# remah
mixed modeling approaches


## install
```
$ pip install remah
Collecting remah
  Downloading remah-0.0.2-py3-none-any.whl.metadata (832 bytes)
Downloading remah-0.0.2-py3-none-any.whl (2.1 kB)
Installing collected packages: remah
Successfully installed remah-0.0.2
```

```
$ pip show remah
Name: remah
Version: 0.0.2
Summary: python package for mixed modeling approaches
Home-page: https://github.com/dudung/remah
Author: Sparisoma Viridi
Author-email: dudung@gmail.com
License: MIT
Location: V:\tf\Lib\site-packages
Requires:
Required-by:
```


## problem
```
$ python
Python 3.12.3 (tags/v3.12.3:f6650f9, Apr  9 2024, 14:05:25) [MSC v.1938 64 bit (AMD64)] on win32
Type "help", "copyright", "credits" or "license" for more information.
>>> import remah
Traceback (most recent call last):
  File "<stdin>", line 1, in <module>
ModuleNotFoundError: No module named 'remah'
```